A data frame which contains information from 1345 unique wheat lines on the Sst1 solid stem locus.
Usage
gene_comp
Arguments
Format
A data frame with 1345 rows and 7 columns:
Trait
A short discription of the phenotype associated with the gene
Chromosome
The chromosome where the gene resides
Gene
The name of the gene
Nursery
The program which produced the gene call for the genotype
Line
A breeder assigned line designation
FullSampleName
A designation unique to the line found in the genotypic matrix
Call
A 'call' given for the allelic state. For this package, it is best to format the non desiarable allele as "non_gene" and the heterozygous state as "het_gene".