Learn R Programming

HaploCatcher (version 1.0.3)

marker_info: Model Gene Compendium Data Set

Description

A data frame which contains marker information of GBS markers found on wheat chromosome 3B. This data pairs with the markers found in "geno_mat" data file associated with the HaploCatcher package.

Usage

marker_info

Arguments

Format

A data frame with 2271 rows and 3 columns:

Marker

The designation of the markers which are found in the genotypic matrix

Chromosome

The chromosome where each marker resides

BP_Position

The position of each marker in basepairs

Examples

Run this code
data("marker_info") #lazy loads the dataset for use in the package

Run the code above in your browser using DataLab