A data frame which contains marker information of GBS markers found on wheat chromosome 3B. This data pairs with the markers found in "geno_mat" data file associated with the HaploCatcher package.
Usage
marker_info
Arguments
Format
A data frame with 2271 rows and 3 columns:
Marker
The designation of the markers which are found in the genotypic matrix